@echo off
REM #############################  Restore.bat  ################################
REM # You can use this batch file to restore backup files using command-line.  #
REM # Just customize the "User Define Section" below with values for your      #
REM # restore action.                                                          #
REM ############################################################################

REM #####################  Start: User Define Section  #########################

REM -----------------------------  BACKUP_SET  ---------------------------------
REM | The name of the backup set that you want to restore                      |
REM | If backup set name is not in English, please use BackupSetID             |
REM | e.g. SET BACKUP_SET="1119083740107"                                      |
REM |  or  SET BACKUP_SET="FileBackupSet-1"                                    |
REM |                                                                          |
REM | You can leave this parameter blank if you are using ACB or have only 1   |
REM | backup set.                                                              |
REM ----------------------------------------------------------------------------
SET BACKUP_SET=

REM -----------------------------  RESTORE_TO  ---------------------------------
REM | Directory to where you want files to be restored                         |
REM | e.g. SET RESTORE_TO="C:\Temp"                                            |
REM ----------------------------------------------------------------------------
SET RESTORE_TO=

REM ----------------------------  RESTORE_FROM  --------------------------------
REM | File/Directory on the backup server that you would like to restore       |
REM | e.g. SET RESTORE_FROM="C:\Data"                                          |
REM ----------------------------------------------------------------------------
SET RESTORE_FROM=

REM ----------------------------  POINT_IN_TIME  -------------------------------
REM | The point-in-time snapshot that you want to restore from the backup      |
REM | server. Use "Current" for the latest backup snapshot                     |
REM | e.g. SET POINT_IN_TIME="2006-10-04-12-57-13"                             |
REM |  or  SET POINT_IN_TIME="Current"                                         |
REM ----------------------------------------------------------------------------
SET POINT_IN_TIME=

REM -------------------------  RESTORE_PERMISSION  -----------------------------
REM | set to "Y" if you want to restore file permissions                       |
REM | set to "N" if you do NOT want to restore file permissions                |
REM ----------------------------------------------------------------------------
SET RESTORE_PERMISSION=

REM --------------------------  SKIP_INVALID_KEY  ------------------------------
REM | set to "Y" if you want to skip restore file with invalid key             |
REM | set to "N" if you want to prompt user to input a correct key             |
REM ----------------------------------------------------------------------------
SET SKIP_INVALID_KEY=

REM -----------------------------  SYNC_OPTION  --------------------------------
REM | set to "Y" if you want to enable sync option                             |
REM | set to "N" if you do NOT want to enable sync option                      |
REM ----------------------------------------------------------------------------
SET SYNC_OPTION=

REM -----------------------  REPLACE_EXISTING_FILE  ----------------------------
REM | set to "-all" to replace all existing file(s) of the same filename       |
REM | set to "-none" to skip all existing file(s) with the same filename       |
REM | set to "" to prompt for selection                                        |
REM ----------------------------------------------------------------------------
SET REPLACE_EXISTING_FILE="-all"

REM ----------------------------  SETTING_HOME  --------------------------------
REM | Directory to your OBM setting home. Default to                           |
REM | "C:\Documents and Settings\%USER%\.obm" when not set.                    |
REM | e.g. SET SETTING_HOME="C:\Documents and Settings\John\.obm"              |
REM ----------------------------------------------------------------------------
SET SETTING_HOME=

REM OPTION:
REM -------------------------------  FILTER  -----------------------------------
REM | Filter out what files you want to restore                                |
REM | -Pattern=xxx-Type=yyy-Target=zzz                                         |
REM | where xxx is the filter pattern,                                         |
REM |       yyy is the filter type, whice can be one of the following:         |
REM |           [exact | exactMatchCase | contains | containsMatchCase|        |
REM |            startWith | startWithMatchCase | endWith | endWithMatchCase]  |
REM |       zzz is the filter target, which can be one of the following:       |
REM |           [toFile | toFileDir | toDir]                                   |
REM |                                                                          |
REM | e.g. SET FILTER=-Pattern=.txt-Type=exact-Target=toFile                   |
REM ----------------------------------------------------------------------------
SET FILTER=

REM ######################  END: User Define Section  ##########################

@echo on
SET APP_HOME=..
SET JAVA_HOME=%APP_HOME%\jvm
SET JAVA_EXE=%JAVA_HOME%\bin\java.exe
SET JAVA_LIB_PATH=-Djava.library.path=%APP_HOME%\bin
SET PATH=%JAVA_HOME%\bin;%APP_HOME%\bin;%PATH%
SET CLASSPATH=%APP_HOME%\bin;%APP_HOME%\bin\obc.jar;%APP_HOME%\bin\obc-lib.jar
SET MAIN_CLASS=Restore

%JAVA_EXE% %JAVA_LIB_PATH% -cp %CLASSPATH% %MAIN_CLASS% -to=%RESTORE_TO% -from=%RESTORE_FROM% -backupset=%BACKUP_SET% %REPLACE_EXISTING_FILE% -date=%POINT_IN_TIME% -setPermission=%RESTORE_PERMISSION% -skipInvalidKey=%SKIP_INVALID_KEY% -sync=%SYNC_OPTION% -Filter=%FILTER% -AppHome=%APP_HOME% -SettingHome=%SETTING_HOME%
pause